<?php
/**
* @package RSMediaGallery!
* @copyright (C) 2011 - 2021 www.rsjoomla.com
* @license GPL, http://www.gnu.org/licenses/gpl-3.0.html
*/

defined('_JEXEC') or die('Restricted access');

class plgContentRSMediaGallery extends JPlugin {
	
	function __construct(&$subject, $params) {
		parent::__construct($subject, $params);

		if (file_exists(JPATH_SITE.'/components/com_rsmediagallery/helpers/route.php')) {
            require_once JPATH_SITE.'/components/com_rsmediagallery/helpers/route.php';
        }
		if (file_exists(JPATH_ADMINISTRATOR.'/components/com_rsmediagallery/helpers/helper.php')) {
			require_once JPATH_ADMINISTRATOR.'/components/com_rsmediagallery/helpers/helper.php';			
			$this->params = RSMediaGalleryHelper::parseParams($this->params);
		}
	}

	public function onContentPrepare($context, &$article, &$params, $page = 0) {

		// Don't run this plugin when the content is being indexed
		if ($context == 'com_finder.indexer') {
            return true;
        }

		// simple performance check to determine whether bot should process further
		if (strpos($article->text, '{rsmediagallery') === false) {
            return true;
        }
		
		if (!file_exists(JPATH_ADMINISTRATOR.'/components/com_rsmediagallery/helpers/helper.php')) {
			$lang = JFactory::getLanguage();

			$lang->load('plg_content_rsmediagallery', JPATH_ADMINISTRATOR);

			JFactory::getApplication()->enqueueMessage(JText::_('PLG_CONTENT_RSMEDIAGALLERY_CONTENT_PLUGIN_COMPONENT_NOT_INSTALLED_OR_UPDATED'), 'warning');
			return true;
		}
		
		$pattern = '/{rsmediagallery\s+(.*?)}/i';

		if (preg_match_all($pattern, $article->text, $matches, PREG_SET_ORDER)) {

            $document 		    = JFactory::getDocument();
            $componentParams    = JComponentHelper::getParams('com_rsmediagallery');
			$min                = JDEBUG ? '' : '.min';

            // CSS
            JHtml::_('stylesheet', 'plg_content_rsmediagallery/style.css', array('relative' => true, 'version' => 'auto'));
            JHtml::_('stylesheet', 'plg_content_rsmediagallery/'.$componentParams->get('contrast', 'light').'.css', array('relative' => true, 'version' => 'auto'));
            JHtml::_('stylesheet', 'plg_content_rsmediagallery/magnific-popup.css', array('relative' => true, 'version' => 'auto'));

			// Javascript
            JHtml::_('jquery.framework');
			$document->addScriptDeclaration('jQuery.noConflict();');

            JHtml::_('script', 'plg_content_rsmediagallery/jquery.magnific-popup'.$min.'.js', array('relative' => true, 'version' => 'auto'));
            JHtml::_('script', 'plg_content_rsmediagallery/jquery.script'.$min.'.js', array('relative' => true, 'version' => 'auto'));

            require_once JPATH_ADMINISTRATOR.'/components/com_rsmediagallery/helpers/helper.php';
		
			foreach ($matches as $index => $match) {
				$match[1]   = html_entity_decode($match[1]);
				$attributes = JUtility::parseAttributes($match[1]);
				$registry 	= new JRegistry(md5($match[1]));
				$registry->loadArray($attributes);				
				$this->params->set('tags', $registry->get('tags'));

				$tmp_params = clone($this->params);
				
				// can't have both, it would look distorted
				if ($registry->get('thumb_width') > 0) {
                    $registry->set('thumb_height', 0);
                } else if ($registry->get('thumb_height') > 0) {
                    $registry->set('thumb_width', 0);
                }

				$tmp_params->merge($registry);
				
				$article->text = str_replace($match[0], $this->_getGallery($tmp_params, $match[0]), $article->text);
			}

			return true;
		}
	}

	protected function _getGallery($params, $text) {

		JFactory::getLanguage()->load('plg_content_rsmediagallery', JPATH_ADMINISTRATOR);

        $document   = JFactory::getDocument();
		$html       = '';
		$tags       = $params->get('tags');
		
		if (!$tags) {
            return $text;
        }
			
		$order 					= $params->get('ordering', $this->params->get('ordering', 'ordering'));
		$direction				= $params->get('direction', $this->params->get('direction', 'ASC'));
		$limit					= (int) $params->get('limit', $this->params->get('limit', 0));
		$show_title				= (int) $params->get('show_title', $this->params->get('show_title', 1));
		$show_description 		= (int) $params->get('show_description', $this->params->get('show_description', 1));
		$show_details_thumb 	= (int) $params->get('show_details_thumb', $this->params->get('show_details_thumb', 1));
		$use_original 			= (int) $params->get('use_original', 0);
		$animation		 		= (int) $params->get('animation');
		$thumb_max_size			= $params->get('thumb_width') ? ' style="max-width: ' . $params->get('thumb_width') . 'px;"' : ' style="max-height: ' . $params->get('thumb_height') . 'px;"';
		$thumb_container_height	= $params->get('thumb_width') ? '' : ' style="padding-top: ' . $params->get('thumb_height') . 'px;"';
		
		$items              	= RSMediaGalleryHelper::getItems($tags, $order, $direction, 0, $limit);

		if ($items) {
			$html .= '<div class="rsmg-content-main-container'.($params->get('center_list') ? ' rsmg-center' : '').'">';
				
            if ($animation) {
                $used_tags = explode(',', $tags);

                $html .= '<ul class="rsmg-content-gallery-filters">';
                $html .= '<li class="filter active" data-filter="all">'.JText::_('PLG_CONTENT_RSMEDIAGALLERY_ALL').'</li>';

                foreach ($used_tags as $tag) {
                    $html .= '<li class="filter" data-filter="'.$this->niceTag($tag).'">'.$this->escape($tag).'</li>';
                }
                $html .= '</ul>';
            }
			
			$html .= '<ul class="rsmg-content-gallery">';
			$itemsrow   = $params->get('itemsrow');
			$itemsrow	= ($itemsrow > 6 ? 6 : ($itemsrow == 5 ? 4 : $itemsrow));

			RSMediaGalleryHelper::addTags($items);

			foreach ($items as $i => $item) {
				$item = RSMediaGalleryHelper::parseItem($item, $params);

                $item_data_attributes = 'data-mfp-src="' . addslashes($item->full) . '"';
                $item_data_attributes .= ' data-max-width="' . $item->full_width . '"';
                $item_data_attributes .= ' data-max-height="' . $item->full_height . '"';

                $item_data_attributes .= ' data-item-id="' . $item->id . '"';
                $item_data_attributes .= ' data-item-title="' . ($show_title ? $this->escape($item->title) : '') . '"';
                $item_data_attributes .= ' data-item-description="' . ($show_description ? $item->full_description : '') . '"';

				$html .= '<li class="rsmg-col-'.$itemsrow.($animation ? ' filtr-item" data-category="'.$this->niceTags($item->tags).'"' : '"').'>';
				$html .= '<div class="rsmg-content-item-container"'.$thumb_max_size.'>';
				$html .= '<a class="rsmg-content-item-link" href="'.addslashes($item->full).'"'.$item_data_attributes.'>';
                $html .= '<div class="rsmg-content-item-thumb-container"'.$thumb_container_height.'>';
                $html .= '<div class="rsmg-content-item-thumb">';
                $html .= '<img src="'.$item->thumb.'" alt="'.$this->escape($item->title).'"/>';
                $html .= '</div>';
                $html .= '</div>';

                if ((($show_title && !empty($item->title)) || ($show_description && !empty($item->full_description))) && $show_details_thumb) {
                    $html .= '<div class="rsmg-content-item-body">';

                    if ($show_title && !empty($item->title)) {
                        $html .= '<h3 class="rsmg-content-item-title">';
                        $html .= $item->title;
                        $html .= '</h3>';
                    }
                    if ($show_description && !empty($item->full_description)) {
                        $html .= '<div class="rsmg-content-item-description">';
                        $html .= $item->full_description;
                        $html .= '</div>';
                    }
                    $html .= '</div>';
                }

                $html .= '</a>';
				$html .= '</div>';
				$html .= '</li>';
			}

			$html .= '</ul>';
			$html .= '</div>';
		}
		
		if ($animation) {
            JHtml::_('script', 'plg_content_rsmediagallery/jquery.filterizr.min.js', array('relative' => true, 'version' => 'auto'));

			$componentParams    = JComponentHelper::getParams('com_rsmediagallery');
            $effects            = array('fade', 'scale', 'rotatex', 'rotatey', 'rotatez');
            $opacity_in_css     = '';
            $opacity_out_css    = '';
            $transform_in_css   = '';
            $transform_out_css  = '';

            foreach ($effects as $effect) {
                if ($componentParams->get('animation_effect_'.$effect)) {
                    if ($effect == 'fade') {
                        $opacity_in_css     .= '1';
                        $opacity_out_css    .= '0';
                    }
                    if ($effect == 'scale') {
                        $transform_in_css   .= 'scale(1) ';
                        $transform_out_css  .= 'scale(0.25) ';
                    }
                    if ($effect == 'rotatex') {
                        $transform_in_css   .= 'rotateX(0deg)';
                        $transform_out_css  .= 'rotateX(-90deg)';
                    }
                    if ($effect == 'rotatey') {
                        $transform_in_css   .= 'rotateY(0deg)';
                        $transform_out_css  .= 'rotateY(-90deg)';
                    }
                    if ($effect == 'rotatez') {
                        $transform_in_css   .= 'rotateZ(0deg)';
                        $transform_out_css  .= 'rotateZ(-90deg)';
                    }
                    if ($effect == 'rotatex' || $effect == 'rotatey' || $effect == 'rotatez') {
                        $transform_in_css .= 'perspective('.$item->thumb_width.'px)';
                        $transform_out_css .= 'perspective('.$item->thumb_width.'px)';
                    }
                }
            }

            $effects_in_css = '{
                opacity     : \''.$opacity_in_css.'\',
                transform   : \''.$transform_in_css.'\',
            }';
            $effects_out_css = '{
                opacity     : \''.$opacity_out_css.'\',
                transform   : \''.$transform_out_css.'\'
            }';

            $document->addScriptDeclaration("
                jQuery(function() {
                    var rsmg_content_gallery_filter,
                        rsmg_content_gallery_filters = '.rsmg-content-gallery-filters .filter';
                    
                    if (jQuery(rsmg_content_gallery_filters).length > 0) {
                        
                        rsmg_content_gallery_filter = jQuery('.rsmg-content-gallery').filterizr({
                            animationDuration   : 0.".$componentParams->get('animation_transition_speed', 0).",
                            layout              : 'sameSize',
                            controlsSelector    : rsmg_content_gallery_filters,
                            gridItemsSelector   : '.rsmg-content-gallery .filtr-item',
                            easing              : '".$componentParams->get('animation_easing', 'ease')."',
                            filterInCss         : ".$effects_in_css.",
                            filterOutCss        : ".$effects_out_css.",
                            callbacks           : {
                                onFilteringEnd  : function() {
                                    rsmgContentInitMagnificPopup();
                                }
                            }
                        });
                        
                        rsmg_content_gallery_filter.filterizr('filter', 'all');
                        
                        jQuery(rsmg_content_gallery_filters).on('click', function() {
                            jQuery(rsmg_content_gallery_filters).removeClass('active');
                            jQuery(this).addClass('active');
                        });
                    }
                });
            ");
		}
		
		return $html;
	}
	
	protected function niceTag($tag) {
		return RSMediaGalleryHelper::niceTag($tag);
	}
	
    protected function niceTags($tags) {
		return RSMediaGalleryHelper::niceTags($tags);
    }
	
	protected function escape($string) {
		return RSMediaGalleryHelper::escape($string);
	}
}